==> reusable_lib-0.3.1-py3-none-any.whl: reusable_lib/reusable_pickle.py <==
#!/usr/bin/env python3
"""Reusable library - PICKLE

MIT License

Copyright (c) 2023 JJR

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

Requirements:
"""

import pickle
import os

def pickle_filesave(obj, filename):
    try:
        with open(filename, 'wb') as outfile:
            pickle.dump(obj, outfile)
    except Exception as e:
        print('ERROR: pickle_filesave', e)
        return 1

    return 0


def pickle_fileload(filename):
    data = None
    try:
        with open(filename, 'r') as infile:
            data = pickle_load(infile)
    except Exception as e:
        print('ERROR: pickle_fileload', e)
        return None
    return data

==> reusable_lib-0.3.3-py3-none-any.whl: reusable_lib/reusable_pickle.py <==
#!/usr/bin/env python3
"""Reusable library - PICKLE

MIT License

Copyright (c) 2023 JJR

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

Requirements:
"""

import pickle
import os

def pickle_filesave(obj, filename):
    try:
        with open(filename, 'wb') as outfile:
            pickle.dump(obj, outfile)
    except Exception as e:
        print('ERROR: pickle_filesave', e)
        return 1

    return 0


def pickle_fileload(filename):
    data = None
    try:
        with open(filename, 'rb') as infile:
            data = pickle.load(infile)
    except Exception as e:
        print('ERROR: pickle_fileload', e)
        return None
    return data
